@@ -110,6 +110,22 @@ class Moji:
             '_SessionToken': cls._SessionToken,
         }).json()
 
+    @classmethod
+    def search_v3(cls, text: str) -> dict:
+        """
+        搜索词
+
+        :param text: 输入文本
+        """
+        return utils.request_post('https://api.mojidict.com/parse/functions/search_v3', json={
+            'langEnv': 'zh-CN_ja',
+            'searchText': text,
+            '_ApplicationId': cls._ApplicationId,
+            '_ClientVersion': cls._ClientVersion,
+            '_InstallationId': cls._InstallationId,
+            '_SessionToken': cls._SessionToken,
+        }).json()
+
     @classmethod
     def search_grammar(cls, text: str) -> dict:
         """
